@@ -17,7 +17,7 @@ import (
 
 var severityFormat map[severity.Severity]string
 
-func DefaultWithMetrics(metrics scanner.Metrics, conciseOutput bool) func(b formatters.ConfigurableFormatter, results scan.Results) error {
+func DefaultWithMetrics(metrics scanner.Metrics, conciseOutput bool, codeTheme string, withColours bool) func(b formatters.ConfigurableFormatter, results scan.Results) error {
 	return func(b formatters.ConfigurableFormatter, results scan.Results) error {
 
 		// we initialise the map here so we respect the colour-ignore options
@@ -53,7 +53,7 @@ func DefaultWithMetrics(metrics scanner.Metrics, conciseOutput bool) func(b form
 
 		_, _ = fmt.Fprintln(b.Writer(), "")
 		for _, group := range groups {
-			printResult(b, group)
+			printResult(b, group, codeTheme, withColours)
 		}
 
 		if !conciseOutput {
@@ -137,7 +137,7 @@ func getOccurrences(first scan.Result, baseDir string) []simpleLocation {
 }
 
 // nolint
-func printResult(b formatters.ConfigurableFormatter, group formatters.GroupedResult) {
+func printResult(b formatters.ConfigurableFormatter, group formatters.GroupedResult, theme string, withColours bool) {
 
 	first := group.Results()[0]
 
@@ -216,7 +216,7 @@ func printResult(b formatters.ConfigurableFormatter, group formatters.GroupedRes
 			strings.Repeat("─", width),
 		)
 
-		if err := highlightCode(b, first); err != nil {
+		if err := highlightCode(b, first, theme, withColours); err != nil {
 			_, _ = fmt.Fprintf(w, tml.Sprintf("  <red><bold>Failed to render code:</bold> %s", err))
 		}
 
@@ -293,16 +293,29 @@ func printMetadata(w io.Writer, result scan.Result, links []string, isRego bool)
 }
 
 // nolint
-func highlightCode(b formatters.ConfigurableFormatter, result scan.Result) error {
+func highlightCode(b formatters.ConfigurableFormatter, result scan.Result, theme string, withColours bool) error {
 
-	code, err := result.GetCode(true)
+	codeOpts := []scan.CodeOption{
+		scan.OptionCodeWithTruncation(true),
+	}
+
+	switch theme {
+	case "dark":
+		codeOpts = append(codeOpts, scan.OptionCodeWithDarkTheme())
+	case "light":
+		codeOpts = append(codeOpts, scan.OptionCodeWithLightTheme())
+	default:
+		codeOpts = append(codeOpts, scan.OptionCodeWithTheme(theme))
+	}
+
+	code, err := result.GetCode(codeOpts...)
 	if err != nil {
 		return err
 	}
 
 	w := b.Writer()
 
-	lines := code.Lines()
+	lines := code.Lines
 
 	if len(lines) == 0 {
 		return nil
@@ -310,7 +323,12 @@ func highlightCode(b formatters.ConfigurableFormatter, result scan.Result) error
 
 	hasOuter := !lines[0].IsCause || !lines[len(lines)-1].IsCause
 
-	for _, line := range lines {
+	for i, line := range lines {
+
+		outputCode := line.Highlighted
+		if !withColours {
+			outputCode = line.Content
+		}
 
 		// if we're rendering the actual issue lines, use red
 		if line.IsCause && result.Status() != scan.StatusPassed {
@@ -326,9 +344,9 @@ func highlightCode(b formatters.ConfigurableFormatter, result scan.Result) error
 				_ = tml.Fprintf(w, " ")
 			} else if code.IsCauseMultiline() {
 				switch {
-				case line.FirstCause:
+				case line.FirstCause || i == 0:
 					_ = tml.Fprintf(w, "<red>┌</red>")
-				case line.LastCause:
+				case line.LastCause || i == len(lines)-1:
 					_ = tml.Fprintf(w, "<red>└</red>")
 				default:
 					_ = tml.Fprintf(w, "<red>│</red>")
@@ -340,9 +358,9 @@ func highlightCode(b formatters.ConfigurableFormatter, result scan.Result) error
 			_ = tml.Fprintf(
 				w,
 				" %s",
-				line.Highlighted,
+				outputCode,
 			)
-			if line.Annotation != "" {
+			if line.Annotation != "" && !code.IsCauseMultiline() {
 				_ = tml.Fprintf(
 					w,
 					" <italic><dim>(%s)",
@@ -369,7 +387,7 @@ func highlightCode(b formatters.ConfigurableFormatter, result scan.Result) error
 				_ = tml.Fprintf(
 					w,
 					"  %s",
-					line.Highlighted,
+					outputCode,
 				)
 			}
 
